pub struct IdentityContext {
pub identifier: String,
pub key: String,
pub traits: HashMap<String, FlagsmithValue>,
}Expand description
Represents identity context for feature flag evaluation.
Fields
identifier: StringThe identity identifier.
key: StringString key used for hashing in percentage splits. If not provided during deserialization, it will be constructed as “environment_key_identifier”.
traits: HashMap<String, FlagsmithValue>Identity traits as a map of trait keys to values.