Mappers module for converting between old and new types
Functions
- add_
identity_ to_ context - Adds identity data to an existing context
- environment_
to_ context - Maps an Environment to an EngineEvaluationContext
Mappers module for converting between old and new types